GEB (Geographical Environmental and Behavioural model) simulates the environment (e.g., hydrology, floods), the individual people, households and organizations as well as their interactions at both small and large scale. The model does so through a "deep" coupling of an agent-based model a hydrological model, a vegetation model and a hydrodynamic model. You can find full documentation [here](https://docs.geb.sh/).

The figure below shows a schematic overview of GEB.

![Schematic model overview of GEB.](https://raw.githubusercontent.com/GEB-model/GEB/refs/heads/main/docs/images/schematic_overview.svg "Schematic model overview")

## Cite as

### Model framework

> de Bruijn, J. A., Smilovic, M., Burek, P., Guillaumot, L., Wada, Y., and Aerts, J. C. J. H.: GEB v0.1: a large-scale agent-based socio-hydrological model – simulating 10 million individual farming households in a fully distributed hydrological model, Geosci. Model Dev., 16, 2437–2454, [https://doi.org/10.5194/gmd-16-2437-2023](https://doi.org/10.5194/gmd-16-2437-2023), 2023.

### Applications

> Bril, V. C., de Bruijn, J., de Moel, H., Sadana, T., Busker, T., Botzen, W. J. W., & Aerts, J. C. J. H.: Assessing the effectiveness of nature-based solutions and building-level flood risk reduction measures: An open-source coupled Model. Water Resources Research, 62, e2025WR041436, [https://doi.org/10.1029/2025WR041436](https://doi.org/10.1029/2025WR041436), 2026.

> Kalthof, M. W. M. L., de Bruijn, J., de Moel, H., Kreibich, H., and Aerts, J. C. J. H.: Adaptive behavior of farmers under consecutive droughts results in more vulnerable farmers: a large-scale agent-based modeling analysis in the Bhima basin, India, NHESS, [https://doi.org/10.5194/nhess-25-1013-2025](https://doi.org/10.5194/nhess-25-1013-2025), 2025.

## Building on the shoulders of giants

1.  Burek, Peter, et al. "Development of the Community Water Model (CWatM v1.04) A high-resolution hydrological model for global and regional assessment of integrated water resources management." (2019).
2.  Langevin, Christian D., et al. Documentation for the MODFLOW 6 groundwater flow model. No. 6-A55. US Geological Survey, 2017.
3.  Tierolf, Lars, et al. "A coupled agent-based model for France for simulating adaptation and migration decisions under future coastal flood risk." Scientific Reports 13.1 (2023): 4176.
4.  Streefkerk, Ileen N., et al. "A coupled agent-based model to analyse human-drought feedbacks for agropastoralists in dryland regions." Frontiers in Water 4 (2023): 1037971.
5.  Joshi, Jaideep, et al. "Plant-FATE-Predicting the adaptive responses of biodiverse plant communities using functional-trait evolution." EGU General Assembly Conference Abstracts. 2022.
6.  Leijnse, Tim, et al. "Modeling compound flooding in coastal systems using a computationally efficient reduced-physics solver: Including fluvial, pluvial, tidal, wind-and wave-driven processes." Coastal Engineering 163 (2021): 103796.


## FAQ

**How is GEB pronounced?**

It’s pronounced as "geb" ([/ɡɛb/](https://en.wikipedia.org/wiki/Help:IPA/English#Key)), with the "g" as in "get" or "gate", aligning with how ancient Egyptians would have *likely* pronounced the name of their god of the Earth: Geb.
